package java.security;

import java.io.IOException;
import java.io.InputStream;
import java.io.FilterInputStream;

public class DigestInputStream extends FilterInputStream
{
    private boolean on;
    protected MessageDigest digest;
    
    public DigestInputStream(InputStream in, MessageDigest messageDigest) {
        super(in);
        this.on = true;
        this.setMessageDigest(messageDigest);
    }
    
    public MessageDigest getMessageDigest() {
        return this.digest;
    }
    
    public void setMessageDigest(MessageDigest digest) {
        this.digest = digest;
    }
    
    @Override
    public int read() throws IOException {
        int read = this.in.read();
        if (this.on && read != -1) {
            this.digest.update((byte)read);
        }
        return read;
    }
    
    @Override
    public int read(byte[] b, int off, int len) throws IOException {
        int read = this.in.read(b, off, len);
        if (this.on && read != -1) {
            this.digest.update(b, off, read);
        }
        return read;
    }
    
    public void on(boolean on) {
        this.on = on;
    }
    
    @Override
    public String toString() {
        return "[Digest Input Stream] " + this.digest.toString();
    }
}
